@@ -3,10 +3,10 @@
  *
  *	Database utility functions for Slony-I
  *
- *	Copyright (c) 2003-2004, PostgreSQL Global Development Group
+ *	Copyright (c) 2003-2005, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	$Id: dbutils.c,v 1.9.2.3 2004/10/13 18:49:53 wieck Exp $
+ *	$Id: dbutils.c,v 1.16.2.1 2006-01-06 17:07:47 cbbrowne Exp $
  *-------------------------------------------------------------------------
  */
 
@@ -29,24 +29,22 @@
 #include "slon.h"
 
 
-static int	slon_appendquery_int(SlonDString *dsp, char *fmt, va_list ap);
+static int	slon_appendquery_int(SlonDString * dsp, char *fmt, va_list ap);
 
-/* 
- * This mutex is used to wrap around PQconnectdb. There's a problem
- * that occurs when your libpq is compiled with libkrb (kerberos)
- * which is not threadsafe.  It is especially odd because I'm not using
- * kerberos. 
- * 
- * This is fixed in libpq in 8.0, but for now (and for older versions
- * we'll just use this mutex. 
+/*
+ * This mutex is used to wrap around PQconnectdb. There's a problem that
+ * occurs when your libpq is compiled with libkrb (kerberos) which is not
+ * threadsafe.	It is especially odd because I'm not using kerberos.
+ *
+ * This is fixed in libpq in 8.0, but for now (and for older versions we'll just
+ * use this mutex.
  *
  */
 static pthread_mutex_t slon_connect_lock = PTHREAD_MUTEX_INITIALIZER;
 
 
-/* ----------
- * slon_connectdb
- * ----------
+/*
+ * ---------- slon_connectdb ----------
  */
 SlonConn *
 slon_connectdb(char *conninfo, char *symname)
@@ -63,22 +61,40 @@ slon_connectdb(char *conninfo, char *symname)
 	if (dbconn == NULL)
 	{
 		slon_log(SLON_ERROR,
-				"slon_connectdb: PQconnectdb(\"%s\") failed\n",
-				conninfo);
+				 "slon_connectdb: PQconnectdb(\"%s\") failed\n",
+				 conninfo);
 		return NULL;
 	}
 	if (PQstatus(dbconn) != CONNECTION_OK)
 	{
 		slon_log(SLON_ERROR,
-				"slon_connectdb: PQconnectdb(\"%s\") failed - %s",
-				conninfo, PQerrorMessage(dbconn));
+				 "slon_connectdb: PQconnectdb(\"%s\") failed - %s",
+				 conninfo, PQerrorMessage(dbconn));
 		PQfinish(dbconn);
 		return NULL;
 	}
+	if (sql_on_connection != NULL)
+	{
+
+		PGresult *res;
+		SlonDString query;
+
+		dstring_init(&query);
+		slon_mkquery(&query, "%s", sql_on_connection);
+		res = PQexec(dbconn, dstring_data(&query));
+		if ( ! ((PQresultStatus(res) == PGRES_TUPLES_OK) ||
+		       (PQresultStatus(res)  == PGRES_COMMAND_OK)) )
+		{
+			slon_log(SLON_ERROR,
+				"query %s failed\n",
+				dstring_data(&query));
+		}
+                PQclear(res);
+	}
 
 	/*
-	 * Embed it into a SlonConn structure used to exchange it with
-	 * the scheduler. On return this new connection object is locked.
+	 * Embed it into a SlonConn structure used to exchange it with the
+	 * scheduler. On return this new connection object is locked.
 	 */
 	conn = slon_make_dummyconn(symname);
 	conn->dbconn = dbconn;
@@ -87,12 +103,11 @@ slon_connectdb(char *conninfo, char *symname)
 }
 
 
-/* ----------
- * slon_disconnectdb
- * ----------
+/*
+ * ---------- slon_disconnectdb ----------
  */
 void
-slon_disconnectdb(SlonConn *conn)
+slon_disconnectdb(SlonConn * conn)
 {
 	/*
 	 * Disconnect the native database connection
@@ -103,16 +118,14 @@ slon_disconnectdb(SlonConn *conn)
 #endif
 
 	/*
-	 * Unlock and destroy the condition and mutex variables
-	 * and free memory.
+	 * Unlock and destroy the condition and mutex variables and free memory.
 	 */
 	slon_free_dummyconn(conn);
 }
 
 
-/* ----------
- * slon_make_dummyconn
- * ----------
+/*
+ * ---------- slon_make_dummyconn ----------
  */
 SlonConn *
 slon_make_dummyconn(char *symname)
@@ -122,7 +135,7 @@ slon_make_dummyconn(char *symname)
 	/*
 	 * Allocate and initialize the SlonConn structure
 	 */
-	conn = (SlonConn *)malloc(sizeof(SlonConn));
+	conn = (SlonConn *) malloc(sizeof(SlonConn));
 	if (conn == NULL)
 	{
 		perror("slon_make_dummyconn: malloc()");
@@ -131,23 +144,22 @@ slon_make_dummyconn(char *symname)
 	memset(conn, 0, sizeof(SlonConn));
 	conn->symname = strdup(symname);
 
-	/* 
+	/*
 	 * Initialize and lock the condition and mutex variables
 	 */
 	pthread_mutex_init(&(conn->conn_lock), NULL);
 	pthread_cond_init(&(conn->conn_cond), NULL);
 	pthread_mutex_lock(&(conn->conn_lock));
-	
+
 	return conn;
 }
 
 
-/* ----------
- * slon_free_dummyconn
- * ----------
+/*
+ * ---------- slon_free_dummyconn ----------
  */
 void
-slon_free_dummyconn(SlonConn *conn)
+slon_free_dummyconn(SlonConn * conn)
 {
 	/*
 	 * Destroy and unlock the condition and mutex variables
@@ -167,16 +179,15 @@ slon_free_dummyconn(SlonConn *conn)
 }
 
 
-/* ----------
- * db_getLocalNodeId
+/*
+ * ---------- db_getLocalNodeId
  *
- *	Query a connection for the value of sequence sl_local_node_id
- * ----------
+ * Query a connection for the value of sequence sl_local_node_id ----------
  */
 int
 db_getLocalNodeId(PGconn *conn)
 {
-	char		query[1024];
+	char		query  [1024];
 	PGresult   *res;
 	int			retval;
 
@@ -184,21 +195,21 @@ db_getLocalNodeId(PGconn *conn)
 	 * Select the last_value from the sl_local_node_id sequence
 	 */
 	snprintf(query, 1024, "select last_value::int4 from %s.sl_local_node_id",
-			rtcfg_namespace);
+			 rtcfg_namespace);
 	res = PQexec(conn, query);
 	if (PQresultStatus(res) != PGRES_TUPLES_OK)
 	{
 		slon_log(SLON_ERROR,
-				"cannot get sl_local_node_id - %s",
-				PQresultErrorMessage(res));
+				 "cannot get sl_local_node_id - %s",
+				 PQresultErrorMessage(res));
 		PQclear(res);
 		return -1;
 	}
 	if (PQntuples(res) != 1)
 	{
 		slon_log(SLON_ERROR,
-				"query '%s' returned %d rows (expected 1)\n",
-				query, PQntuples(res));
+				 "query '%s' returned %d rows (expected 1)\n",
+				 query, PQntuples(res));
 		PQclear(res);
 		return -1;
 	}
@@ -208,7 +219,7 @@ db_getLocalNodeId(PGconn *conn)
 	 */
 	retval = strtol(PQgetvalue(res, 0, 0), NULL, 10);
 	PQclear(res);
-	
+
 	return retval;
 }
 
@@ -222,7 +233,7 @@ db_getLocalNodeId(PGconn *conn)
 int
 db_checkSchemaVersion(PGconn *conn)
 {
-	char		query[1024];
+	char		query  [1024];
 	PGresult   *res;
 	int			retval = 0;
 
@@ -230,24 +241,24 @@ db_checkSchemaVersion(PGconn *conn)
 	 * Select the version number from the schema
 	 */
 	snprintf(query, 1024, "select %s.slonyVersion()",
-			rtcfg_namespace);
+			 rtcfg_namespace);
 	res = PQexec(conn, query);
 	if (PQresultStatus(res) != PGRES_TUPLES_OK)
 	{
 		slon_log(SLON_ERROR,
-				"cannot get Slony-I schema version - %s",
-				PQresultErrorMessage(res));
+				 "cannot get Slony-I schema version - %s",
+				 PQresultErrorMessage(res));
 		slon_log(SLON_ERROR,
-				"please upgrade Slony-I schema to version %s\n",
-				SLONY_I_VERSION_STRING);
+				 "please upgrade Slony-I schema to version %s\n",
+				 SLONY_I_VERSION_STRING);
 		PQclear(res);
 		return -1;
 	}
 	if (PQntuples(res) != 1)
 	{
 		slon_log(SLON_ERROR,
-				"query '%s' returned %d rows (expected 1)\n",
-				query, PQntuples(res));
+				 "query '%s' returned %d rows (expected 1)\n",
+				 query, PQntuples(res));
 		PQclear(res);
 		return -1;
 	}
@@ -258,37 +269,37 @@ db_checkSchemaVersion(PGconn *conn)
 	if (strcmp(PQgetvalue(res, 0, 0), SLONY_I_VERSION_STRING) != 0)
 	{
 		slon_log(SLON_ERROR,
-				"Slony-I schema version is %s\n",
-				PQgetvalue(res, 0, 0));
+				 "Slony-I schema version is %s\n",
+				 PQgetvalue(res, 0, 0));
 		slon_log(SLON_ERROR,
-				"please upgrade Slony-I schema to version %s\n",
-				SLONY_I_VERSION_STRING);
+				 "please upgrade Slony-I schema to version %s\n",
+				 SLONY_I_VERSION_STRING);
 		retval = -1;
 	}
 	PQclear(res);
-	
+
 	/*
 	 * Select the version number from the module
 	 */
 	snprintf(query, 1024, "select %s.getModuleVersion()",
-			rtcfg_namespace);
+			 rtcfg_namespace);
 	res = PQexec(conn, query);
 	if (PQresultStatus(res) != PGRES_TUPLES_OK)
 	{
 		slon_log(SLON_ERROR,
-				"cannot get Slony-I module version - %s",
-				PQresultErrorMessage(res));
+				 "cannot get Slony-I module version - %s",
+				 PQresultErrorMessage(res));
 		slon_log(SLON_ERROR,
-				"please upgrade Slony-I shared module to version %s\n",
-				SLONY_I_VERSION_STRING);
+				 "please upgrade Slony-I shared module to version %s\n",
+				 SLONY_I_VERSION_STRING);
 		PQclear(res);
 		return -1;
 	}
 	if (PQntuples(res) != 1)
 	{
 		slon_log(SLON_ERROR,
-				"query '%s' returned %d rows (expected 1)\n",
-				query, PQntuples(res));
+				 "query '%s' returned %d rows (expected 1)\n",
+				 query, PQntuples(res));
 		PQclear(res);
 		return -1;
 	}
@@ -299,32 +310,29 @@ db_checkSchemaVersion(PGconn *conn)
 	if (strcmp(PQgetvalue(res, 0, 0), SLONY_I_VERSION_STRING) != 0)
 	{
 		slon_log(SLON_ERROR,
-				"Slony-I module version is %s\n",
-				PQgetvalue(res, 0, 0));
+				 "Slony-I module version is %s\n",
+				 PQgetvalue(res, 0, 0));
 		slon_log(SLON_ERROR,
-				"please upgrade Slony-I shared module to version %s\n",
-				SLONY_I_VERSION_STRING);
+				 "please upgrade Slony-I shared module to version %s\n",
+				 SLONY_I_VERSION_STRING);
 		retval = -1;
 	}
 	PQclear(res);
-	
+
 	return retval;
 }
 
 
-/* ----------
- * slon_mkquery
+/*
+ * ---------- slon_mkquery
  *
- *	A simple query formatting and quoting function using dynamic string
- *	buffer allocation.
- *	Similar to sprintf() it uses formatting symbols:
- *		%s		String argument
- *		%q		Quoted literal (\ and ' will be escaped)
- *		%d		Integer argument
- * ----------
+ * A simple query formatting and quoting function using dynamic string buffer
+ * allocation. Similar to sprintf() it uses formatting symbols: %s
+ * tring argument %q		Quoted literal (\ and ' will be escaped) %d
+ * nteger argument ----------
  */
 int
-slon_mkquery(SlonDString *dsp, char *fmt, ...)
+slon_mkquery(SlonDString * dsp, char *fmt,...)
 {
 	va_list		ap;
 
@@ -340,14 +348,13 @@ slon_mkquery(SlonDString *dsp, char *fmt, ...)
 }
 
 
-/* ----------
- * slon_appendquery
+/*
+ * ---------- slon_appendquery
  *
- *	Append query string material to an existing dynamic string.
- * ----------
+ * Append query string material to an existing dynamic string. ----------
  */
 int
-slon_appendquery(SlonDString *dsp, char *fmt, ...)
+slon_appendquery(SlonDString * dsp, char *fmt,...)
 {
 	va_list		ap;
 
@@ -361,71 +368,76 @@ slon_appendquery(SlonDString *dsp, char *fmt, ...)
 }
 
 
-/* ----------
- * slon_appendquery_int
+/*
+ * ---------- slon_appendquery_int
  *
- *	Implementation of slon_mkquery() and slon_appendquery().
- * ----------
+ * Implementation of slon_mkquery() and slon_appendquery(). ----------
  */
 static int
-slon_appendquery_int(SlonDString *dsp, char *fmt, va_list ap)
+slon_appendquery_int(SlonDString * dsp, char *fmt, va_list ap)
 {
 	char	   *s;
-	char		buf[64];
+	char		buf    [64];
 
 	while (*fmt)
 	{
-		switch(*fmt)
+		switch (*fmt)
 		{
 			case '%':
 				fmt++;
-				switch(*fmt)
+				switch (*fmt)
 				{
-					case 's':	s = va_arg(ap, char *);
-								dstring_append(dsp, s);
-								fmt++;
-								break;
+					case 's':
+						s = va_arg(ap, char *);
+						dstring_append(dsp, s);
+						fmt++;
+						break;
 
-					case 'q':	s = va_arg(ap, char *);
-								while (*s != '\0')
-								{
-									switch (*s)
-									{
-										case '\'':
-											dstring_addchar(dsp, '\'');
-											break;
-										case '\\':
-											dstring_addchar(dsp, '\\');
-											break;
-										default:
-											break;
-									}
-									dstring_addchar(dsp, *s);
-									s++;
-								}
-								fmt++;
-								break;
+					case 'q':
+						s = va_arg(ap, char *);
+						while (s && *s != '\0')
+						{
+							switch (*s)
+							{
+								case '\'':
+									dstring_addchar(dsp, '\'');
+									break;
+								case '\\':
+									dstring_addchar(dsp, '\\');
+									break;
+								default:
+									break;
+							}
+							dstring_addchar(dsp, *s);
+							s++;
+						}
+						fmt++;
+						break;
 
-					case 'd':	sprintf(buf, "%d", va_arg(ap, int));
-								dstring_append(dsp, buf);
-								fmt++;
-								break;
+					case 'd':
+						sprintf(buf, "%d", va_arg(ap, int));
+						dstring_append(dsp, buf);
+						fmt++;
+						break;
 
-					default:	dstring_addchar(dsp, '%');
-								dstring_addchar(dsp, *fmt);
-								fmt++;
-								break;
-				}
-				break;
-
-			case '\\':	fmt++;
+					default:
+						dstring_addchar(dsp, '%');
 						dstring_addchar(dsp, *fmt);
 						fmt++;
 						break;
+				}
+				break;
 
-			default:	dstring_addchar(dsp, *fmt);
-						fmt++;
-						break;
+			case '\\':
+				fmt++;
+				dstring_addchar(dsp, *fmt);
+				fmt++;
+				break;
+
+			default:
+				dstring_addchar(dsp, *fmt);
+				fmt++;
+				break;
 		}
 	}
 
@@ -434,12 +446,10 @@ slon_appendquery_int(SlonDString *dsp, char *fmt, va_list ap)
 	return 0;
 }
 
-
 /*
  * Local Variables:
- *  tab-width: 4
- *  c-indent-level: 4
- *  c-basic-offset: 4
+ *	tab-width: 4
+ *	c-indent-level: 4
+ *	c-basic-offset: 4
  * End:
  */
-
