@@ -3,10 +3,10 @@
  *
  *	Event scheduling subsystem for slon.
  *
- *	Copyright (c) 2003-2004, PostgreSQL Global Development Group
+ *	Copyright (c) 2003-2006, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	$Id: scheduler.c,v 1.15.2.1 2004/09/30 17:45:06 cbbrowne Exp $
+ *	$Id: scheduler.c,v 1.20.2.1 2006-01-06 17:07:47 cbbrowne Exp $
  *-------------------------------------------------------------------------
  */
 
@@ -15,10 +15,10 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <signal.h>
 #include <unistd.h>
 #include <string.h>
 #include <errno.h>
-#include <signal.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -36,48 +36,40 @@
 #define PF_LOCAL PF_UNIX
 #endif
 
-
-/* ----------
- * Static data
- * ----------
+/*
+ * ---------- Static data ----------
  */
-static int				sched_status = SCHED_STATUS_OK;
+static int	sched_status = SCHED_STATUS_OK;
 
-static int				sched_numfd = 0;
-static fd_set			sched_fdset_read;
-static fd_set			sched_fdset_write;
-static int				sched_wakeuppipe[2];
-static SlonConn		   *sched_waitqueue_head = NULL;
-static SlonConn		   *sched_waitqueue_tail = NULL;
+static int	sched_numfd = 0;
+static fd_set sched_fdset_read;
+static fd_set sched_fdset_write;
+static SlonConn *sched_waitqueue_head = NULL;
+static SlonConn *sched_waitqueue_tail = NULL;
 
-static pthread_t		sched_main_thread;
-static pthread_t		sched_scheduler_thread;
+static pthread_t sched_main_thread;
+static pthread_t sched_scheduler_thread;
 
-static pthread_mutex_t	sched_master_lock = PTHREAD_MUTEX_INITIALIZER;
-static pthread_cond_t	sched_master_cond = PTHREAD_COND_INITIALIZER;
-
-static sigset_t			sched_sigset;
+static pthread_mutex_t sched_master_lock = PTHREAD_MUTEX_INITIALIZER;
+static pthread_cond_t sched_master_cond = PTHREAD_COND_INITIALIZER;
 
 
-/* ----------
- * Local functions
- * ----------
+/*
+ * ---------- Local functions ----------
  */
-static void			   *sched_mainloop(void *);
-static void				sched_sighandler(int signo);
-static void				sched_sighuphandler(int signo);
-static void				sched_add_fdset(int fd, fd_set *fds);
-static void				sched_remove_fdset(int fd, fd_set *fds);
+static void *sched_mainloop(void *);
+static void sched_add_fdset(int fd, fd_set * fds);
+static void sched_remove_fdset(int fd, fd_set * fds);
+static void sched_shutdown();
 
 
-/* ----------
- * sched_start_mainloop
+/*
+ * ---------- sched_start_mainloop
  *
- *	Called from main() before starting up any worker thread.
+ * Called from main() before starting up any worker thread.
  *
- *	This will spawn the event scheduling thread that does the
- *	central select(2) system call.
- * ----------
+ * This will spawn the event scheduling thread that does the central select(2)
+ * system call. ----------
  */
 int
 sched_start_mainloop(void)
@@ -87,17 +79,6 @@ sched_start_mainloop(void)
 	 */
 	sched_main_thread = pthread_self();
 
-	/*
-	 * Block signals. Since sched_start_mainloop() is called before
-	 * any other thread is created, this will be inherited by all
-	 * threads in the system. 
-	 */
-	sigemptyset(&sched_sigset);
-	sigaddset(&sched_sigset, SIGHUP);
-	sigaddset(&sched_sigset, SIGINT);
-	sigaddset(&sched_sigset, SIGTERM);
-	pthread_sigmask(SIG_BLOCK, &sched_sigset, NULL);
-
 	/*
 	 * Grab the scheduler master lock
 	 */
@@ -147,41 +128,16 @@ sched_start_mainloop(void)
 }
 
 
-/* ----------
- * sched_wait_mainloop
+/*
+ * ---------- sched_wait_mainloop
  *
- *	Called from main() after all working threads according to the
- *	initial configuration are started. Will wait until the scheduler
- *	mainloop terminates.
- * ----------
+ * Called from main() after all working threads according to the initial
+ * configuration are started. Will wait until the scheduler mainloop
+ * terminates. ----------
  */
 int
 sched_wait_mainloop(void)
 {
-	int		signo;
-
-	/*
-	 * Wait for signal.
-	 */
-	sigemptyset(&sched_sigset);
-	sigaddset(&sched_sigset, SIGHUP);
-	sigaddset(&sched_sigset, SIGINT);
-	sigaddset(&sched_sigset, SIGTERM);
-	sigwait(&sched_sigset, &signo);
-
-	sigemptyset(&sched_sigset);
-	pthread_sigmask(SIG_SETMASK, &sched_sigset, NULL);
-
-	switch (signo)
-	{
-		case SIGHUP:	sched_sighuphandler(signo);
-						break;
-
-		case SIGINT:
-		case SIGTERM:	sched_sighandler(signo);
-						break;
-	}
-
 	/*
 	 * Wait for the scheduler to finish.
 	 */
@@ -190,24 +146,22 @@ sched_wait_mainloop(void)
 		perror("sched_wait_mainloop: pthread_join()");
 		return -1;
 	}
-
 	return 0;
 }
 
 
-/* ----------
- * sched_wait_conn
+/*
+ * ---------- sched_wait_conn
  *
- *	Assumes that the thread holds the lock on conn->conn_lock.
+ * Assumes that the thread holds the lock on conn->conn_lock.
  *
- *	Adds the connection to the central wait queue and wakes up
- *	the scheduler thread to reloop onto the select(2) call.
- * ----------
+ * Adds the connection to the central wait queue and wakes up the scheduler
+ * thread to reloop onto the select(2) call. ----------
  */
 int
-sched_wait_conn(SlonConn *conn, int condition)
+sched_wait_conn(SlonConn * conn, int condition)
 {
-	int		rc;
+	int			rc;
 
 	/*
 	 * Grab the master lock and check that we're in normal runmode
@@ -220,8 +174,8 @@ sched_wait_conn(SlonConn *conn, int condition)
 	}
 
 	/*
-	 * Remember the event we're waiting for and add the database 
-	 * connection to the fdset(s)
+	 * Remember the event we're waiting for and add the database connection to
+	 * the fdset(s)
 	 */
 	conn->condition = condition;
 	if (condition & SCHED_WAIT_SOCK_READ)
@@ -235,8 +189,8 @@ sched_wait_conn(SlonConn *conn, int condition)
 	DLLIST_ADD_HEAD(sched_waitqueue_head, sched_waitqueue_tail, conn);
 
 	/*
-	 * Give the scheduler thread a heads up, release the master lock
-	 * and wait for it to tell us that the event we're waiting for happened.
+	 * Give the scheduler thread a heads up, release the master lock and wait
+	 * for it to tell us that the event we're waiting for happened.
 	 */
 	if (write(sched_wakeuppipe[1], "x", 1) < 0)
 	{
@@ -264,18 +218,17 @@ sched_wait_conn(SlonConn *conn, int condition)
 }
 
 
-/* ----------
- * sched_wait_time
+/*
+ * ---------- sched_wait_time
  *
- *	Assumes that the thread holds the lock on conn->conn_lock.
+ * Assumes that the thread holds the lock on conn->conn_lock.
  *
- *	Like sched_wait_conn() but with a timeout. Can be called without
- *	any read/write condition to wait for to resemble a pure timeout
- *	mechanism.
+ * Like sched_wait_conn() but with a timeout. Can be called without any
+ * read/write condition to wait for to resemble a pure timeout mechanism.
  * ----------
  */
 int
-sched_wait_time(SlonConn *conn, int condition, int msec)
+sched_wait_time(SlonConn * conn, int condition, int msec)
 {
 	struct timeval *tv = &(conn->timeout);
 
@@ -283,8 +236,8 @@ sched_wait_time(SlonConn *conn, int condition, int msec)
 	 * Calculate the end-time of the desired timeout.
 	 */
 	gettimeofday(tv, NULL);
-	tv->tv_sec += (long)(msec / 1000) + 
-					(((msec % 1000) * 1000) + tv->tv_usec) / 1000000;
+	tv->tv_sec += (long)(msec / 1000) +
+		(((msec % 1000) * 1000) + tv->tv_usec) / 1000000;
 	tv->tv_usec = (tv->tv_usec + (msec % 1000) * 1000) % 1000000;
 
 	/*
@@ -294,14 +247,13 @@ sched_wait_time(SlonConn *conn, int condition, int msec)
 }
 
 
-/* ----------
- * sched_msleep
+/*
+ * ---------- sched_msleep
  *
- *	Use the schedulers event loop to sleep for msec milliseconds.
- * ----------
+ * Use the schedulers event loop to sleep for msec milliseconds. ----------
  */
 int
-sched_msleep(SlonNode *node, int msec)
+sched_msleep(SlonNode * node, int msec)
 {
 	SlonConn   *conn;
 	char		dummyconn_name[64];
@@ -322,16 +274,15 @@ sched_msleep(SlonNode *node, int msec)
 }
 
 
-/* ----------
- * sched_get_status
+/*
+ * ---------- sched_get_status
  *
- *	Return the current scheduler status in a thread safe fashion
- * ----------
+ * Return the current scheduler status in a thread safe fashion ----------
  */
 int
 sched_get_status(void)
 {
-	int		status;
+	int			status;
 
 	pthread_mutex_lock(&sched_master_lock);
 	status = sched_status;
@@ -340,16 +291,15 @@ sched_get_status(void)
 }
 
 
-/* ----------
- * sched_wakeup_node
+/*
+ * ---------- sched_wakeup_node
  *
- *	Wakeup the threads (listen and worker) of one or all remote
- *	nodes to cause them rechecking the current runtime status or
- *	adjust their configuration to changes.
- * ----------
+ * Wakeup the threads (listen and worker) of one or all remote nodes to cause
+ * them rechecking the current runtime status or adjust their configuration
+ * to changes. ----------
  */
 int
-sched_wakeup_node (int no_id)
+sched_wakeup_node(int no_id)
 {
 	SlonConn   *conn;
 	int			num_wakeup = 0;
@@ -382,39 +332,37 @@ sched_wakeup_node (int no_id)
 			slon_abort();
 		}
 	}
-
 	pthread_mutex_unlock(&sched_master_lock);
 
 	remoteWorker_wakeup(no_id);
 
 	slon_log(SLON_DEBUG2, "sched_wakeup_node(): no_id=%d "
-			"(%d threads + worker signaled)\n", no_id, num_wakeup);
+			 "(%d threads + worker signaled)\n", no_id, num_wakeup);
 
 	return num_wakeup;
 }
 
 
-/* ----------
- * sched_mainloop
+/*
+ * ---------- sched_mainloop
  *
- *	The thread handling the master scheduling.
- * ----------
+ * The thread handling the master scheduling. ----------
  */
 static void *
 sched_mainloop(void *dummy)
 {
-	fd_set			rfds;
-	fd_set			wfds;
-	int				rc;
-	SlonConn	   *conn;
-	SlonConn	   *next;
-	struct timeval	min_timeout;
+	fd_set		rfds;
+	fd_set		wfds;
+	int			rc;
+	SlonConn   *conn;
+	SlonConn   *next;
+	struct timeval min_timeout;
 	struct timeval *tv;
-	int				i;
+	int			i;
 
 	/*
-	 * Grab the scheduler master lock. This will wait until the
-	 * main thread acutally blocks on the master cond.
+	 * Grab the scheduler master lock. This will wait until the main thread
+	 * acutally blocks on the master cond.
 	 */
 	pthread_mutex_lock(&sched_master_lock);
 
@@ -424,32 +372,21 @@ sched_mainloop(void *dummy)
 	FD_ZERO(&sched_fdset_read);
 	FD_ZERO(&sched_fdset_write);
 
-	/*
-	 * Create a pipe used by the main thread to cleanly
-	 * wakeup the scheduler on signals.
-	 */
-	if (pipe(sched_wakeuppipe) < 0)
-	{
-		perror("sched_mainloop: pipe()");
-		sched_status = SCHED_STATUS_ERROR;
-		pthread_cond_signal(&sched_master_cond);
-		pthread_exit(NULL);
-	}
 	sched_add_fdset(sched_wakeuppipe[0], &sched_fdset_read);
 
 	/*
-	 * Done with all initialization. Let the main thread go
-	 * ahead and get everyone else dancing.
+	 * Done with all initialization. Let the main thread go ahead and get
+	 * everyone else dancing.
 	 */
 	pthread_cond_signal(&sched_master_cond);
 
 	/*
 	 * And we are now entering the endless loop of scheduling events
 	 */
-	while(sched_status == SCHED_STATUS_OK)
+	while (sched_status == SCHED_STATUS_OK)
 	{
-		struct timeval	now;
-		struct timeval	timeout;
+		struct timeval now;
+		struct timeval timeout;
 
 		/*
 		 * Make copies of the file descriptor sets for select(2)
@@ -465,9 +402,9 @@ sched_mainloop(void *dummy)
 		}
 
 		/*
-		 * Check if any of the connections in the wait queue
-		 * have reached there timeout. While doing so, we also
-		 * remember the closest timeout in the future.
+		 * Check if any of the connections in the wait queue have reached
+		 * their timeout. While doing so, we also remember the closest timeout
+		 * in the future.
 		 */
 		tv = NULL;
 		gettimeofday(&now, NULL);
@@ -478,18 +415,17 @@ sched_mainloop(void *dummy)
 			if (conn->condition & SCHED_WAIT_CANCEL)
 			{
 				/*
-				 * Some other thread wants this thread to
-				 * wake up.
+				 * Some other thread wants this thread to wake up.
 				 */
-				DLLIST_REMOVE(sched_waitqueue_head, 
-							sched_waitqueue_tail, conn);
+				DLLIST_REMOVE(sched_waitqueue_head,
+							  sched_waitqueue_tail, conn);
 
 				if (conn->condition & SCHED_WAIT_SOCK_READ)
-					sched_remove_fdset(PQsocket(conn->dbconn), 
-									&sched_fdset_read);
+					sched_remove_fdset(PQsocket(conn->dbconn),
+									   &sched_fdset_read);
 				if (conn->condition & SCHED_WAIT_SOCK_WRITE)
 					sched_remove_fdset(PQsocket(conn->dbconn),
-									&sched_fdset_write);
+									   &sched_fdset_write);
 
 				pthread_mutex_lock(&(conn->conn_lock));
 				pthread_cond_signal(&(conn->conn_cond));
@@ -498,14 +434,13 @@ sched_mainloop(void *dummy)
 				conn = next;
 				continue;
 			}
-
 			if (conn->condition & SCHED_WAIT_TIMEOUT)
 			{
 				/*
-				 * This connection has a timeout. Calculate the
-				 * time until that.
+				 * This connection has a timeout. Calculate the time until
+				 * that.
 				 */
-				timeout.tv_sec  = conn->timeout.tv_sec  - now.tv_sec;
+				timeout.tv_sec = conn->timeout.tv_sec - now.tv_sec;
 				timeout.tv_usec = conn->timeout.tv_usec - now.tv_usec;
 				while (timeout.tv_usec < 0)
 				{
@@ -517,23 +452,22 @@ sched_mainloop(void *dummy)
 				 * Check if the timeout has elapsed
 				 */
 				if (timeout.tv_sec < 0 ||
-						(timeout.tv_sec == 0 && timeout.tv_usec < 20000))
+					(timeout.tv_sec == 0 && timeout.tv_usec < 20000))
 				{
 					/*
-					 * Remove the connection from the wait queue. We
-					 * consider everything closer than 20 msec being
-					 * elapsed to avoid a full scheduler round just
-					 * for one kernel tick.
+					 * Remove the connection from the wait queue. We consider
+					 * everything closer than 20 msec being elapsed to avoid a
+					 * full scheduler round just for one kernel tick.
 					 */
-					DLLIST_REMOVE(sched_waitqueue_head, 
-								sched_waitqueue_tail, conn);
+					DLLIST_REMOVE(sched_waitqueue_head,
+								  sched_waitqueue_tail, conn);
 
 					if (conn->condition & SCHED_WAIT_SOCK_READ)
-						sched_remove_fdset(PQsocket(conn->dbconn), 
-										&sched_fdset_read);
+						sched_remove_fdset(PQsocket(conn->dbconn),
+										   &sched_fdset_read);
 					if (conn->condition & SCHED_WAIT_SOCK_WRITE)
 						sched_remove_fdset(PQsocket(conn->dbconn),
-										&sched_fdset_write);
+										   &sched_fdset_write);
 
 					pthread_mutex_lock(&(conn->conn_lock));
 					pthread_cond_signal(&(conn->conn_cond));
@@ -545,17 +479,16 @@ sched_mainloop(void *dummy)
 					 * Timeout not elapsed. Remember the nearest.
 					 */
 					if (tv == NULL ||
-							timeout.tv_sec < min_timeout.tv_sec ||
-							(timeout.tv_sec == min_timeout.tv_sec &&
-								timeout.tv_usec < min_timeout.tv_usec))
+						timeout.tv_sec < min_timeout.tv_sec ||
+						(timeout.tv_sec == min_timeout.tv_sec &&
+						 timeout.tv_usec < min_timeout.tv_usec))
 					{
 						tv = &min_timeout;
-						min_timeout.tv_sec  = timeout.tv_sec;
+						min_timeout.tv_sec = timeout.tv_sec;
 						min_timeout.tv_usec = timeout.tv_usec;
 					}
 				}
 			}
-
 			conn = next;
 		}
 
@@ -581,7 +514,7 @@ sched_mainloop(void *dummy)
 		 */
 		if (FD_ISSET(sched_wakeuppipe[0], &rfds))
 		{
-			char	buf[1];
+			char		buf    [1];
 
 			rc--;
 			if (read(sched_wakeuppipe[0], buf, 1) != 1)
@@ -590,14 +523,19 @@ sched_mainloop(void *dummy)
 				sched_status = SCHED_STATUS_ERROR;
 				break;
 			}
+
+			if (buf[0] == 'p')
+			{
+				sched_status = SCHED_STATUS_SHUTDOWN;
+			}
 		}
 
 		/*
-		 * Check all remaining connections if the IO condition the
-		 * thread is waiting for has occured.
+		 * Check all remaining connections if the IO condition the thread is
+		 * waiting for has occured.
 		 */
 		conn = sched_waitqueue_head;
-		while(rc > 0 && conn)
+		while (rc > 0 && conn)
 		{
 			if (conn->condition & SCHED_WAIT_SOCK_READ)
 			{
@@ -610,21 +548,20 @@ sched_mainloop(void *dummy)
 					pthread_mutex_unlock(&(conn->conn_lock));
 					rc--;
 
-					DLLIST_REMOVE(sched_waitqueue_head, 
-								sched_waitqueue_tail, conn);
+					DLLIST_REMOVE(sched_waitqueue_head,
+								  sched_waitqueue_tail, conn);
 
 					if (conn->condition & SCHED_WAIT_SOCK_READ)
-						sched_remove_fdset(PQsocket(conn->dbconn), 
-										&sched_fdset_read);
+						sched_remove_fdset(PQsocket(conn->dbconn),
+										   &sched_fdset_read);
 					if (conn->condition & SCHED_WAIT_SOCK_WRITE)
 						sched_remove_fdset(PQsocket(conn->dbconn),
-										&sched_fdset_write);
+										   &sched_fdset_write);
 
 					conn = next;
 					continue;
 				}
 			}
-
 			if (conn->condition & SCHED_WAIT_SOCK_WRITE)
 			{
 				if (FD_ISSET(PQsocket(conn->dbconn), &wfds))
@@ -636,34 +573,37 @@ sched_mainloop(void *dummy)
 					pthread_mutex_unlock(&(conn->conn_lock));
 					rc--;
 
-					DLLIST_REMOVE(sched_waitqueue_head, 
-								sched_waitqueue_tail, conn);
+					DLLIST_REMOVE(sched_waitqueue_head,
+								  sched_waitqueue_tail, conn);
 
 					if (conn->condition & SCHED_WAIT_SOCK_READ)
-						sched_remove_fdset(PQsocket(conn->dbconn), 
-										&sched_fdset_read);
+						sched_remove_fdset(PQsocket(conn->dbconn),
+										   &sched_fdset_read);
 					if (conn->condition & SCHED_WAIT_SOCK_WRITE)
 						sched_remove_fdset(PQsocket(conn->dbconn),
-										&sched_fdset_write);
+										   &sched_fdset_write);
 
 					conn = next;
 					continue;
 				}
 			}
-
 			conn = conn->next;
 		}
 	}
 
 	/*
-	 * If we reach here the scheduler runmode has been changed by
-	 * by the main threads signal handler. We currently hold the
-	 * master lock. First we close the scheduler heads-up socket
-	 * pair so nobody will think we're listening any longer.
+	 * If we reach here the scheduler runmode has been changed by by the main
+	 * threads signal handler. We currently hold the master lock. First we
+	 * close the scheduler heads-up socket pair so nobody will think we're
+	 * listening any longer.
 	 */
+
+	/*
 	close(sched_wakeuppipe[0]);
+	sched_wakeuppipe[0] = -1;
 	close(sched_wakeuppipe[1]);
-	sched_wakeuppipe[0] = sched_wakeuppipe[1] = -1;
+	sched_wakeuppipe[1] = -1;
+	*/
 
 	/*
 	 * Then we cond_signal all connections that are in the queue.
@@ -676,15 +616,15 @@ sched_mainloop(void *dummy)
 		pthread_cond_signal(&(conn->conn_cond));
 		pthread_mutex_unlock(&(conn->conn_lock));
 
-		DLLIST_REMOVE(sched_waitqueue_head, 
-					sched_waitqueue_tail, conn);
+		DLLIST_REMOVE(sched_waitqueue_head,
+					  sched_waitqueue_tail, conn);
 
 		if (conn->condition & SCHED_WAIT_SOCK_READ)
-			sched_remove_fdset(PQsocket(conn->dbconn), 
-							&sched_fdset_read);
+			sched_remove_fdset(PQsocket(conn->dbconn),
+							   &sched_fdset_read);
 		if (conn->condition & SCHED_WAIT_SOCK_WRITE)
 			sched_remove_fdset(PQsocket(conn->dbconn),
-							&sched_fdset_write);
+							   &sched_fdset_write);
 
 		conn = next;
 	}
@@ -697,26 +637,25 @@ sched_mainloop(void *dummy)
 }
 
 
-/* ----------
- * sched_sighandler
+/*
+ * ---------- sched_sighandler
  *
- *	After starting up the sole purpose of the main thread (the original
- *	process) is to respond to signals while waiting for the scheduler to
- *	finish. The signal handler is here because it is actually
- *	sched_start_mainloop() that arranges for the signal handling and
- *	sched_wait_mainloop() that enables them. And the only one really
- *	interested in the signals is the scheduler thread ... but that's doing
- *	select(2) mainly and we have to avoid race conditions with signals.
- * ----------
+ * After starting up the sole purpose of the main thread (the original process)
+ * is to respond to signals while waiting for the scheduler to finish. The
+ * signal handler is here because it is actually sched_start_mainloop() that
+ * arranges for the signal handling and sched_wait_mainloop() that enables
+ * them. And the only one really interested in the signals is the scheduler
+ * thread ... but that's doing select(2) mainly and we have to avoid race
+ * conditions with signals. ----------
  */
 static void
-sched_sighandler(int signo)
+sched_shutdown()
 {
 	/*
 	 * Lock the master mutex and make sure that we are the main thread
 	 */
 	pthread_mutex_lock(&sched_master_lock);
-	if (pthread_self() != sched_main_thread)
+	if (!pthread_equal(pthread_self(), sched_main_thread))
 	{
 		slon_log(SLON_FATAL, "sched_sighandler: called in non-main thread\n");
 		slon_abort();
@@ -751,23 +690,15 @@ sched_sighandler(int signo)
 }
 
 
-static void
-sched_sighuphandler(int signo)
-{
-	slon_restart_request = true;
-	sched_sighandler(signo);
-}
 
-
-/* ----------
- * sched_add_fdset
+/*
+ * ---------- sched_add_fdset
  *
- *	Add a file descriptor to one of the global scheduler sets and
- *	adjust sched_numfd accordingly.
- * ----------
+ * Add a file descriptor to one of the global scheduler sets and adjust
+ * sched_numfd accordingly. ----------
  */
 static void
-sched_add_fdset(int fd, fd_set *fds)
+sched_add_fdset(int fd, fd_set * fds)
 {
 	FD_SET(fd, fds);
 	if (fd >= sched_numfd)
@@ -775,15 +706,14 @@ sched_add_fdset(int fd, fd_set *fds)
 }
 
 
-/* ----------
- * sched_add_fdset
+/*
+ * ---------- sched_add_fdset
  *
- *	Remove a file descriptor from one of the global scheduler sets and
- *	adjust sched_numfd accordingly.
- * ----------
+ * Remove a file descriptor from one of the global scheduler sets and adjust
+ * sched_numfd accordingly. ----------
  */
 static void
-sched_remove_fdset(int fd, fd_set *fds)
+sched_remove_fdset(int fd, fd_set * fds)
 {
 	FD_CLR(fd, fds);
 	if (sched_numfd == (fd + 1))
@@ -798,13 +728,3 @@ sched_remove_fdset(int fd, fd_set *fds)
 		}
 	}
 }
-
-
-/*
- * Local Variables:
- *  tab-width: 4
- *  c-indent-level: 4
- *  c-basic-offset: 4
- * End:
- */
-
