@@ -1,16 +1,19 @@
 /*-------------------------------------------------------------------------
  * sync_thread.c
  *
- *	Implementation of the thread generating SYNC evens.
+ *	Implementation of the thread that generates SYNC events.
  *
- *	Copyright (c) 2003-2004, PostgreSQL Global Development Group
+ *	Copyright (c) 2003-2006, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	$Id: sync_thread.c,v 1.11.2.1 2004/09/30 17:45:06 cbbrowne Exp $
+ *	$Id: sync_thread.c,v 1.15.2.1 2006-01-06 17:07:47 cbbrowne Exp $
  *-------------------------------------------------------------------------
  */
 
 
+/* Note that in 1.1, generate_sync_event() is a stored procedure that
+   does roughly the same thing as this... */
+
 #include <pthread.h>
 
 #include <stdio.h>
@@ -28,18 +31,17 @@
 #include "slon.h"
 
 
-/* ----------
- * Global variables
- * ----------
+/*
+ * ---------- Global variables ----------
  */
-int		sync_interval = 10000;
-int		sync_interval_timeout = 60000;
+int			sync_interval;
+int			sync_interval_timeout;
 
 
-/* ----------
- * slon_localSyncThread
+/*
+ * ---------- slon_localSyncThread
  *
- *	Generate SYNC event if local database activity created new log info.
+ * Generate SYNC event if local database activity created new log info.
  * ----------
  */
 void *
@@ -47,14 +49,14 @@ syncThread_main(void *dummy)
 {
 	SlonConn   *conn;
 	char		last_actseq_buf[64];
-	SlonDString	query1;
-	SlonDString	query2;
+	SlonDString query1;
+	SlonDString query2;
 	PGconn	   *dbconn;
 	PGresult   *res;
 	int			timeout_count;
 
 	slon_log(SLON_DEBUG1,
-			"syncThread: thread starts\n");
+			 "syncThread: thread starts\n");
 
 	/*
 	 * Connect to the local database
@@ -64,63 +66,63 @@ syncThread_main(void *dummy)
 	dbconn = conn->dbconn;
 
 	/*
-	 * We don't initialize the last known action sequence to the
-	 * actual value. This causes that we create a SYNC event
-	 * allways on startup, just in case.
+	 * We don't initialize the last known action sequence to the actual value.
+	 * This causes that we create a SYNC event allways on startup, just in
+	 * case.
 	 */
 	last_actseq_buf[0] = '\0';
 
 	/*
-	 * Build the query that starts a transaction and retrieves
-	 * the last value from the action sequence.
+	 * Build the query that starts a transaction and retrieves the last value
+	 * from the action sequence.
 	 */
 	dstring_init(&query1);
-	slon_mkquery(&query1, 
-			"start transaction;"
-			"set transaction isolation level serializable;"
-			"select last_value from %s.sl_action_seq;",
-			rtcfg_namespace);
+	slon_mkquery(&query1,
+				 "start transaction;"
+				 "set transaction isolation level serializable;"
+				 "select last_value from %s.sl_action_seq;",
+				 rtcfg_namespace);
 
 	/*
 	 * Build the query that calls createEvent() for the SYNC
 	 */
 	dstring_init(&query2);
 	slon_mkquery(&query2,
-			"select %s.createEvent('_%s', 'SYNC', NULL);",
-			rtcfg_namespace, rtcfg_cluster_name);
+				 "select %s.createEvent('_%s', 'SYNC', NULL);",
+				 rtcfg_namespace, rtcfg_cluster_name);
 
 	timeout_count = (sync_interval_timeout == 0) ? 0 :
-			sync_interval_timeout - sync_interval;
+		sync_interval_timeout - sync_interval;
 	while (sched_wait_time(conn, SCHED_WAIT_SOCK_READ, sync_interval) == SCHED_STATUS_OK)
 	{
 		/*
-		 * Start a serializable transaction and get the last value
-		 * from the action sequence number.
+		 * Start a serializable transaction and get the last value from the
+		 * action sequence number.
 		 */
 		res = PQexec(dbconn, dstring_data(&query1));
 		if (PQresultStatus(res) != PGRES_TUPLES_OK)
 		{
 			slon_log(SLON_FATAL,
-					"syncThread: \"%s\" - %s",
-					dstring_data(&query1), PQresultErrorMessage(res));
+					 "syncThread: \"%s\" - %s",
+					 dstring_data(&query1), PQresultErrorMessage(res));
 			PQclear(res);
 			slon_abort();
 			break;
 		}
 
 		/*
-		 * Check if it's identical to the last know seq or if the
-		 * sync interval timeout has arrived.
+		 * Check if it's identical to the last known seq or if the sync
+		 * interval timeout has arrived.
 		 */
 		if (sync_interval_timeout != 0)
 			timeout_count -= sync_interval;
 
 		if (strcmp(last_actseq_buf, PQgetvalue(res, 0, 0)) != 0 ||
-				timeout_count < 0)
+			timeout_count < 0)
 		{
 			/*
-			 * Action sequence has changed, generate a SYNC event
-			 * and read the resulting currval of the event sequence.
+			 * Action sequence has changed, generate a SYNC event and read the
+			 * resulting currval of the event sequence.
 			 */
 			strcpy(last_actseq_buf, PQgetvalue(res, 0, 0));
 
@@ -129,17 +131,17 @@ syncThread_main(void *dummy)
 			if (PQresultStatus(res) != PGRES_TUPLES_OK)
 			{
 				slon_log(SLON_FATAL,
-						"syncThread: \"%s\" - %s",
-						dstring_data(&query2), PQresultErrorMessage(res));
+						 "syncThread: \"%s\" - %s",
+						 dstring_data(&query2), PQresultErrorMessage(res));
 				PQclear(res);
 				slon_abort();
 				break;
 			}
 			slon_log(SLON_DEBUG2,
-					"syncThread: new sl_action_seq %s - SYNC %s\n", 
-					last_actseq_buf, PQgetvalue(res, 0, 0));
+					 "syncThread: new sl_action_seq %s - SYNC %s\n",
+					 last_actseq_buf, PQgetvalue(res, 0, 0));
 			PQclear(res);
-			
+
 			/*
 			 * Commit the transaction
 			 */
@@ -147,8 +149,8 @@ syncThread_main(void *dummy)
 			if (PQresultStatus(res) != PGRES_COMMAND_OK)
 			{
 				slon_log(SLON_FATAL,
-						"syncThread: \"commit transaction;\" - %s",
-						PQresultErrorMessage(res));
+						 "syncThread: \"commit transaction;\" - %s",
+						 PQresultErrorMessage(res));
 				PQclear(res);
 				slon_abort();
 			}
@@ -158,7 +160,7 @@ syncThread_main(void *dummy)
 			 * Restart the timeout on a sync.
 			 */
 			timeout_count = (sync_interval_timeout == 0) ? 0 :
-					sync_interval_timeout - sync_interval;
+				sync_interval_timeout - sync_interval;
 		}
 		else
 		{
@@ -170,8 +172,8 @@ syncThread_main(void *dummy)
 			if (PQresultStatus(res) != PGRES_COMMAND_OK)
 			{
 				slon_log(SLON_FATAL,
-						"syncThread: \"rollback transaction;\" - %s",
-						PQresultErrorMessage(res));
+						 "syncThread: \"rollback transaction;\" - %s",
+						 PQresultErrorMessage(res));
 				PQclear(res);
 				slon_abort();
 			}
@@ -187,12 +189,10 @@ syncThread_main(void *dummy)
 	pthread_exit(NULL);
 }
 
-
 /*
  * Local Variables:
- *  tab-width: 4
- *  c-indent-level: 4
- *  c-basic-offset: 4
+ *	tab-width: 4
+ *	c-indent-level: 4
+ *	c-basic-offset: 4
  * End:
  */
-
